@@ -18,14 +18,18 @@
 
 #include "apptemplateitem.h"
 #include "apptemplatesmodel.h"
-#include "choicepage.h"
 #include "logging.h"
 
-AppTemplatesModel::AppTemplatesModel(ChoicePage *parent)
+AppTemplatesModel::AppTemplatesModel(QObject *parent)
     : QStandardItemModel(parent)
 {
 }
 
+QHash<int, QByteArray> AppTemplatesModel::roleNames() const
+{
+    return {{Qt::DisplayRole, "name"}, {DescriptionFileRole, "descriptionFile"}, {PictureNameRole, "pictureName"}, {BaseNameRole, "baseName"}};
+}
+
 void extractTemplateDescriptions()
 {
     QStringList templateArchives;
@@ -44,7 +48,7 @@ void extractTemplateDescriptions()
     if (!dir.exists())
         dir.mkpath(localDescriptionsDir);
 
-    for (const QString &archName : std::as_const(templateArchives)) {
+    for (const auto &archName : std::as_const(templateArchives)) {
         qCDebug(KAPPTEMPLATE) << "processing template" << archName;
 #ifdef Q_WS_WIN
         KZip templateArchive(archName);
@@ -112,7 +116,6 @@ void AppTemplatesModel::refresh()
         KConfigGroup general(&templateConfig, QStringLiteral("General"));
         QString name = general.readEntry("Name");
         QString category = general.readEntry("Category");
-        qCDebug(KAPPTEMPLATE) << "category " << category;
         QString description = general.readEntry("Comment");
         QString picture = general.readEntry("Icon");
         AppTemplateItem *templateItem = createItem(name, category);
@@ -130,7 +133,6 @@ AppTemplateItem *AppTemplatesModel::createItem(const QString &name, const QStrin
     QStringList currentPath;
     for (const QString &entry : path) {
         currentPath << entry;
-        qCDebug(KAPPTEMPLATE) << "current path " << currentPath;
         if (!m_templateItems.contains(currentPath.join("/"))) {
             AppTemplateItem *item = new AppTemplateItem(entry);
             parent->appendRow(item);
@@ -162,3 +164,20 @@ QVariant AppTemplatesModel::headerData(int section, Qt::Orientation orientation,
     }
     return QVariant();
 }
+
+void AppTemplatesModel::loadFromFiles(const QStringList &selectedFiles)
+{
+    const QString saveLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kdevappwizard/templates/");
+
+    QDir dir(saveLocation);
+    if (!dir.exists()) {
+        dir.mkpath(QStringLiteral("."));
+    }
+
+    for (const QString &fileName : selectedFiles) {
+        QFileInfo info(fileName);
+        QFile::copy(fileName, saveLocation + info.fileName());
+    }
+
+    refresh();
+}
